@@ -11,10 +11,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-SUPPORTED_CDI_VERSIONS = ['2.9']
-VERSION = '0.3.0'
+SUPPORTED_CDI_VERSIONS = ['2.9', '2.10']
+VERSION = '0.3.1'
 TELEMETRY = '/telemetry'
 USER_COUNT = '/users/count'
+USER_DELETE = '/user/remove'
 USERS = '/users'
 TELEMETRY_SUPERTOKENS_API_URL = 'https://api.supertokens.io/0/st/telemetry'
 TELEMETRY_SUPERTOKENS_API_VERSION = '2'
