@@ -33,3 +33,7 @@ def get_users_newest_first(limit: Union[int, None] = None, pagination_token: Uni
 
 def get_user_count(include_recipe_ids: List[str] = None) -> int:
     return sync(Supertokens.get_instance().get_user_count(include_recipe_ids))
+
+
+def delete_user(user_id: str) -> None:
+    return sync(Supertokens.get_instance().delete_user(user_id))
